#!/bin/bash
#SBATCH --job-name=vInt
#SBATCH --ntasks=1
#SBATCH --cpus-per-task=48
#SBATCH --output=logs/vert_int_%j.out
#SBATCH --error=logs/vert_int_%j.err
#SBATCH --time=1:00:00
#SBATCH --account=bsc32          
#SBATCH --qos=debug #bsc_es             


# Configuración más robusta de variables
export EXPID="a936"
export START_DATE="2018-01-01"
export END_DATE="2018-06-30"
export OUTPUT_DIR="/esarchive/scratch/hnavarro/InterpolatedVertData"
export STATION_FILE="/esarchive/scratch/hnavarro/brc_stations/abscoef/jordistns/stations_2018_jordi.json"

# Crear directorio de logs si no existe
mkdir -p logs

# Cargar módulos (mejor con verificación)
if ! source load_modules.sh 2>> logs/modules_${SLURM_JOB_ID}.err; then
    echo "Error loading modules" >&2
    exit 1
fi

# Verificar existencia de archivos
if [[ ! -f "$STATION_FILE" ]]; then
    echo "Station file $STATION_FILE not found!" >&2
    exit 1
fi

# Ejecución
/apps/SINGULARITY/extras/nord3_singu_es python -u vertint_mainv03.py \
    --expid "$EXPID" \
    --start_date "$START_DATE" \
    --end_date "$END_DATE" \
    --output_dir "$OUTPUT_DIR" \
    --station_file "$STATION_FILE"